@@ -1,5 +1,5 @@
 import os
-from pywizard.resources.file import directory
+from pywizard.resources.file import directory, file_
 from pywizard.resources.shell import shell
 from pywizard.templating import tpl
 from pywizard.worker import worker
@@ -13,11 +13,14 @@ def ssl_fake_cert(
         ):
     def certs_are_here():
         return os.path.exists(path + '/' + keyname) and \
-               os.path.exists(path + '/' + csrname) and os.path.exists(path + '/' + crtname)
+            os.path.exists(path + '/' + csrname) and os.path.exists(path + '/' + crtname)
 
     directory(path)
 
+    file_(path + '/ssl.conf', content=tpl('ssl.conf', locals()))
     shell(tpl('fake_ssl_script.sh', locals()), if_not=certs_are_here)
 
-    worker.env.template_engine.globals['ssl_key_path'] = path + '/' + keyname
-    worker.env.template_engine.globals['ssl_cert_path'] = path + '/' + crtname
+    template_engine = worker.env.get_template_engine()
+
+    template_engine.globals['ssl_key_path'] = path + '/' + keyname
+    template_engine.globals['ssl_cert_path'] = path + '/' + crtname
